#!/bin/bash
# lds-get-wrapper.sh by Tim Riker <Tim@Rikers.org>

# setup
root=$(cd ../..;pwd)
sed "s|ROOT|$root|" < config.txt > $root/src/config.py || exit

# backup files
cd ..
GZIP=--best tar czf ../../timriker.tgz timriker

if [ -z "$NOGET" ] ; then
 # remove old stuff
 # but not the cache
 #rm -r $root/data/lds.org
 rm -r $root/data/timriker
 rm -r $root/data/lds.org_clean
 # run lds-get
 cd $root/src || exit
 #$root/src/lds-get.py || exit
 until $root/src/lds-get.py ; do date ; done
fi

# cleanup
cd $root/data || exit
tmp=postlds.tmp
lst=postlds.lst
rm -r lds

# merge in our layout files
cp -a timriker lds

# merge in the cleaned html files
cp -a lds.org_clean/* lds/

# strip relative paths
cd $root/data/lds || exit
perl -p -i -e 's~\.\./lds\.org_clean/~~' index.html
for dir in bd bm dc ensign gs jst music manuals nt ot pgp ; do
 perl -p -i -e 's~\.\./lds\.org_clean/~~' $(find $dir -type f)
 perl -p -i -e "s~\.\./$dir/~~" $(find $dir -type f)
done

cd $root/data || exit
find lds -type f | sort > $lst

# char replacement to simple ascii and
# verify that we are pure ascii
for a in $(cat $lst) ; do
 echo -n "$a:"
 grep charset= $a
 #if iconv -f ASCII -t ASCII -o $a $tmp ; then
 if find $a -size +1024k | grep -q $a ; then
   echo $a too big
   rm $a
   continue
 fi
 if iconv -f ASCII -t ASCII -o $tmp $a 2>/dev/null ; then
  echo -e -n "ASCII \r"
 elif iconv -f UTF-8 -t UTF-8 -o $tmp $a 2>/dev/null ; then
  echo -e -n "UTF-8 \r"
 elif iconv -f WINDOWS-1252 -t UTF-8 -o $tmp $a 2>/dev/null ; then
  echo -e -n "WINDOWS-1252 \r"
 elif iconv -f ISO-8859-1 -t UTF-8 -o $tmp $a 2>/dev/null ; then
  echo -e -n "ISO-8859-1 \r"
 else
  echo "$root/data/$a failed see $(pwd)/$tmp"
  exit
 fi
 sed \
   -e 's/&#145;/‘/g' \
   -e "s/&#146;/’/g" \
   -e 's/&#147;/“/g' \
   -e 's/&#148;/”/g' \
   -e 's/&#151;/–/g' \
   -e 's/&#169;/\&copy;/g' \
   -e 's/&#182;/\&para;/g' \
   -e 's/&#8217;/\&rsquo;/g' \
   -e 's/&#8211;/\&ndash;/g' \
   -e 's/&#8212;/\&mdash;/g' \
   -e 's/&#9658;/►/g' \
   -e 's/&para;/¶/g' \
   -e 's/&hellip;/…/g' \
   -e 's/&lsquo;/‘/g' \
   -e "s/&rsquo;/’/g" \
   -e 's/&ldquo;/“/g' \
   -e 's/&rdquo;/”/g' \
   -e 's/&[mn]dash;/–/g' \
   -e 's/\<ISO-8859-1\>/utf-8/gi' \
   -e 's/[ \t ]\+/ /g' \
   -e 's/ *$//g' \
   -e 's/^ *//g' \
   -e 's/[ \t ]\+/ /g' \
   -e 's/[ÀÁÂÃÄÅ]/A/g' \
   -e 's/Æ/AE/g' \
   -e 's/[ÈÉÊË]/E/g' \
   -e 's/[ÌÍÎÏ]/I/g' \
   -e 's/Ñ/N/g' \
   -e 's/[ÒÓÔÕÖØ]/O/g' \
   -e 's/[ÙÚÛÜ]/U/g' \
   -e 's/Ý/Y/g' \
   -e 's/[àáâãäå]/a/g' \
   -e 's/æ/a/g' \
   -e 's/ç/c/g' \
   -e 's/[èéêë]/e/g' \
   -e 's/[ìíîï]/i/g' \
   -e 's/ñ/n/g' \
   -e 's/[òóôõöø]/o/g' \
   -e 's/[ùúûü]/u/g' \
   -e 's/[ýÿ]/y/g' \
   -e 's/[“”]/"/g' \
   -e "s/[‘’]/'/g" \
   -e "s/[–—]/-/g" \
   -e "s/…/.../g" \
   -e "s/•/*/g" \
   -e 's/►/->/g' \
   -e 's/►/->/g' \
   -e 's/¶/\&para;/g' \
   -e 's/©/\&copy;/g' \
   -e 's/™/\&trade;/g' \
   < $tmp > $a
done
rm $tmp
echo ''

GZIP=--best tar czfT lds.tgz $lst
rm lds.zip
zip -9 -ll -@ lds < $lst
rm $lst

if [ -x /usr/bin/plucker-build ] ; then
 /usr/bin/plucker-build --charset=utf-8 --maxdepth 100 --stayonhost --zlib-compression --launchable --pluckerhome $root/data/ --doc-file lds --home-url file:/lds/index.html --url-pattern 'file:/lds/.*'
fi

echo output:
output="$root/data/lds.tgz $root/data/lds.zip $root/../timriker.tgz $root/data/lds.pdb"
ls -l $output
rsync -av $output /var/www/
(cd /var/www;rm -r lds;tar xzvf lds.tgz)
exit

===============================================================
# verify that we are pure ascii
for a in $(cat postlds.lst) ; do
 iconv -f ASCII -t ASCII -o /dev/null $a
done

#char replacement in lds-get as of 1.5
for a in $(cat $lst) ; do
 echo -e -n "$a \r"
 sed \
   -e 's/&#145;/`/g' \
   -e "s/&#146;/'/g" \
   -e 's/&#147;/"/g' \
   -e 's/&#148;/"/g' \
   -e 's/&#151;/--/g' \
   -e 's/&#182;/\&para;/g' \
   -e 's/\x85/.../g' \
   -e 's/\x91/`/g' \
   -e "s/\x92/'/g" \
   -e 's/\x93/"/g' \
   -e 's/\x94/"/g' \
   -e 's/\x95/\&bull;/g' \
   -e 's/\x96/--/g' \
   -e 's/\x99/\&trade;/g' \
   -e 's/\r//g' \
   -e 's/[ \t][ \t]*/ /g' \
   -e 's/[ \t]$//g' \
   -e 's/^[ \t]//g' \
   < $a > $tmp
 if iconv -f ASCII -t ASCII < $tmp > $a ; then
  true
 else
  echo "$a"
  exit
 fi
done
rm $tmp
exit
